import { createRouter, createWebHistory } from 'vue-router'

import Login from '@/views/Login.vue'
import Reset from '@/views/Reset.vue'
import Home from '@/views/Home.vue'
import Dashboard from '@/views/Dashboard.vue'
import Error from '@/views/error/404.vue'
import OrderList from '@/views/order/index.vue'
import ProductionComplete from '@/views/production/complete.vue'
import { getToken} from '@/api/axios'
import UserPage from '@/views/UserPage.vue'

const router = createRouter({
  history: createWebHistory(),
  routes: [
    {
      path: '/',
      redirect: '/user/login',
      component: Home,
      children: [
        {
          path: '/dashboard',
          component: Dashboard,
        },
        {
          path: '/order/list',
          component: OrderList
        },
        {
          path: '/production/complete',
          component: ProductionComplete
        },
        {
          path: '/system/user',
          component: UserPage
        }
      ],
    },
    // 登录
    {
      path: '/user/login',
      component: Login,
    },
    {
      path: '/user/reset',
      component: Reset,
    },
    // 其他路由
    {
      path: '/:pathMatch(.*)*',
      component: Error,
    },
  ],
})
router.beforeEach((to, _from, next) => {
  const token = getToken()
  if (!token && to.path !== '/user/login') {
    next({ path: '/user/login' })
    return
  }
  next()
})
export default router
